@@ -16,20 +16,20 @@ def basic_table(read_type, sheet_name, read_path, columns_to_keep, columns_renam
     
     for column, operator, value in filters:
         if operator == "==":
-            df = df[df[column] == value]
+            df_basic_table = df_basic_table[df_basic_table[column] == value]
         elif operator == "!=":
-            df = df[df[column] != value]
+            df_basic_table = df_basic_table[df_basic_table[column] != value]
         elif operator == ">":
-            df = df[df[column] > value]
+            df_basic_table = df_basic_table[df_basic_table[column] > value]
         elif operator == ">=":
-            df = df[df[column] >= value]
+            df_basic_table = df_basic_table[df_basic_table[column] >= value]
         elif operator == "<":
-            df = df[df[column] < value]
+            df_basic_table = df_basic_table[df_basic_table[column] < value]
         elif operator == "<=":
-            df = df[df[column] <= value]
+            df_basic_table = df_basic_table[df_basic_table[column] <= value]
+
+    df_basic_table = df_basic_table.groupby(group_by).aggregate(aggregate_columns)
 
-    df = df.groupby(group_by).aggregate(aggregate_columns)
-    
     return df_basic_table
 
 
